==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/visualstudio/kotlin/outputs/GetExtensionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.visualstudio.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * The response to an extension resource GET request.
 * @property id Unique identifier of the resource.
 * @property location Resource location.
 * @property name Resource name.
 * @property plan The extension plan that was purchased.
 * @property properties Resource properties.
 * @property tags Resource tags.
 * @property type Resource type.
 */
public data class GetExtensionResult(
    public val id: String,
    public val location: String? = null,
    public val name: String,
    public val plan: ExtensionResourcePlanResponse? = null,
    public val properties: Map<String, String>,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.visualstudio.outputs.GetExtensionResult):
            GetExtensionResult = GetExtensionResult(
            id = javaType.id(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            plan = javaType.plan().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.visualstudio.kotlin.outputs.ExtensionResourcePlanResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            properties = javaType.properties().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/visualstudio/kotlin/outputs/GetExtensionResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.visualstudio.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * The response to an extension resource GET request.
 * @property id Unique identifier of the resource.
 * @property location Resource location.
 * @property name Resource name.
 * @property plan The extension plan that was purchased.
 * @property properties Resource properties.
 * @property tags Resource tags.
 * @property type Resource type.
 */
public data class GetExtensionResult(
    public val id: String,
    public val location: String? = null,
    public val name: String,
    public val plan: ExtensionResourcePlanResponse? = null,
    public val properties: Map<String, String>,
    public val tags: Map<String, String>? = null,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.visualstudio.outputs.GetExtensionResult): GetExtensionResult = GetExtensionResult(
            id = javaType.id(),
            location = javaType.location().map({ args0 -> args0 }).orElse(null),
            name = javaType.name(),
            plan = javaType.plan().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.visualstudio.kotlin.outputs.ExtensionResourcePlanResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            properties = javaType.properties().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
        )
    }
}
